@@ -9,6 +9,7 @@ use Poz::Types::object;
 use Poz::Types::array;
 use Poz::Types::enum;
 use Poz::Types::union;
+use Poz::Types::is;
 
 sub new {
     my ($class) = @_;
@@ -82,6 +83,11 @@ sub union {
     return Poz::Types::union->new(@validators);
 }
 
+sub is {
+    my ($self, $isa) = @_;
+    return Poz::Types::is->new($isa);
+}
+
 1;
 
 =head1 NAME
@@ -165,6 +171,12 @@ Creates a new enum type with the given options.
 
 Creates a new union type with the given validators.
 
+=head2 is
+
+    my $is_type = $builder->is($isa);
+
+Creates a new is type with the given class.
+
 =head1 LICENSE
 
 Copyright (C) ytnobody.
